<?php

/*-----------------------------------------------------------------------------------

	Here we have all the custom functions for the theme
	Please be extremely cautious editing this file,
	When things go wrong, they tend to go wrong in a big way.
	You have been warned!

-----------------------------------------------------------------------------------*/

add_theme_support( 'automatic-feed-links' );

/*-----------------------------------------------------------------------------------*/
/*	Custom Menu
/*-----------------------------------------------------------------------------------*/
function register_main_menus() {
	register_nav_menus(
		array(
			'header-nav' => __( 'Header Nav','themejunkie' ),
		)
	);
}

if (function_exists('register_nav_menus')) add_action( 'init', 'register_main_menus' );

/*-----------------------------------------------------------------------------------*/
/*	Load Translation Text Domain
/*-----------------------------------------------------------------------------------*/

load_theme_textdomain( 'themejunkie', TEMPLATEPATH . '/lang' );

/*-----------------------------------------------------------------------------------*/
/*	Post Formats
/*-----------------------------------------------------------------------------------*/

$formats = array( 
			'aside',
			'link', 
			'image', 
			'quote', 
			'audio',
			'video');

add_theme_support( 'post-formats', $formats ); 

add_post_type_support( 'post', 'post-formats' );

/*-----------------------------------------------------------------------------------*/
/*	JS Includes
/*-----------------------------------------------------------------------------------*/

function jsIncludes() {
	wp_enqueue_script('jquery');

}
add_action ('get_header', 'jsIncludes');

/*-----------------------------------------------------------------------------------*/
/*	Custom Gravatar Support
/*-----------------------------------------------------------------------------------*/

function tj_custom_gravatar( $avatar_defaults ) {
    $tj_avatar = get_template_directory_uri() . '/images/gravatar.png';
    $avatar_defaults[$tj_avatar] = 'Custom Gravatar (/images/gravatar.png)';
    return $avatar_defaults;
}
add_filter( 'avatar_defaults', 'tj_custom_gravatar' );


/*-----------------------------------------------------------------------------------*/
/*	Change Default Excerpt Length
/*-----------------------------------------------------------------------------------*/

function tj_excerpt_length($length) {
return 17; }
add_filter('excerpt_length', 'tj_excerpt_length');

/*-----------------------------------------------------------------------------------*/
/*	Exclude pages from search
/*-----------------------------------------------------------------------------------*/

function tj_exclude_pages($query) {
        if ($query->is_search) {
        $query->set('post_type', 'post');
                                }
        return $query;
}
add_filter('pre_get_posts','tj_exclude_pages');

/*-----------------------------------------------------------------------------------*/
/*	Configure Excerpt String
/*-----------------------------------------------------------------------------------*/

function tj_excerpt_more($excerpt) {
return str_replace('[...]', '...', $excerpt); }
add_filter('wp_trim_excerpt', 'tj_excerpt_more');


/*-----------------------------------------------------------------------------------*/
/*	Register and load common JS
/*-----------------------------------------------------------------------------------*/

function tj_register_js() {
	if (!is_admin()) {
		// comment out the next two lines to load the local copy of jQuery
		wp_deregister_script('jquery');
//		wp_register_script('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js');
        wp_register_script('jquery', get_template_directory_uri().'/includes/js/jquery-1.6.1.min.js', 'jquery');
		wp_register_script('tj_custom', get_template_directory_uri() . '/includes/js/jquery.custom.js', 'jquery', '1.0', TRUE);
		//wp_register_script('tj_shortcodes', get_template_directory_uri() . '/includes/js/jquery.shortcodes.js', 'jquery');
        wp_register_script('tj_cookie', get_template_directory_uri() . '/includes/js/cookie.jquery.js', 'jquery');
        wp_register_script('jquery-ui-custom', get_template_directory_uri() . '/includes/js/jquery-ui-1.8.5.custom.min.js', 'jquery');
        wp_register_script('jquery-lazyload', get_template_directory_uri() . '/includes/js/jquery.lazyload.js', 'jquery');

        wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-ui-custom');
		//wp_enqueue_script('tj_shortcodes');
		wp_enqueue_script('tj_cookie');
        wp_enqueue_script('tj_custom');
        wp_enqueue_script('jquery-lazyload');
		
	}
}
add_action('init', 'tj_register_js');


/*-----------------------------------------------------------------------------------*/
/*	Register and load admin javascript
/*-----------------------------------------------------------------------------------*/

function tj_admin_js($hook) {
	if ($hook == 'post.php' || $hook == 'post-new.php') {
		wp_register_script('tj-admin', get_template_directory_uri() . '/includes/js/jquery.custom.admin.js', 'jquery');
		wp_enqueue_script('tj-admin');
	}
}
add_action('admin_enqueue_scripts','tj_admin_js',10,1);


/*-----------------------------------------------------------------------------------*/
/*	Load contact template javascript
/*-----------------------------------------------------------------------------------*/

function tj_contact_js() {
	if (is_page_template('template-contact.php') ) 
		wp_register_script('validation', 'http://ajax.microsoft.com/ajax/jquery.validate/1.7/jquery.validate.min.js', 'jquery');
		wp_enqueue_script('validation');
}
add_action('wp_print_scripts', 'tj_contact_js');


/*-----------------------------------------------------------------------------------*/
/* Load scripts for single pages
/*-----------------------------------------------------------------------------------*/

function tj_single_scripts() {
	
	if(is_singular()) 
		
		wp_register_script('easing', get_template_directory_uri().'/includes/js/jquery.easing.1.3.js', 'jquery');
		wp_enqueue_script( 'comment-reply' );
		wp_enqueue_script( 'easing' );
		
	if(is_singular() && has_post_format('image'))
	
		wp_register_script('prettyPhoto', get_template_directory_uri().'/includes/js/prettyPhoto.js', 'jquery');
		wp_enqueue_script( 'prettyPhoto' );
		
	if(is_singular() && has_post_format('gallery') || get_post_type() == 'portfolio')
		
		wp_register_script('jPlayer', get_template_directory_uri().'/includes/js/jquery.jplayer.min.js', 'jquery');
		wp_enqueue_script( 'jPlayer' );
		
	if(is_singular() && has_post_format('video') || has_post_format('audio') )
	
		wp_register_script('jPlayer', get_template_directory_uri().'/includes/js/jquery.jplayer.min.js', 'jquery');
		wp_enqueue_script( 'jPlayer' );
}
add_action('wp_print_scripts', 'tj_single_scripts');


/*-----------------------------------------------------------------------------------*/
/*	Scripts for blog pages
/*-----------------------------------------------------------------------------------*/

function tj_non_singular_scripts() {
	if(!is_singular())

        wp_register_script('jquery', get_template_directory_uri().'/includes/js/jquery-1.6.1.min.js', 'jquery');
		wp_register_script('masonry', get_template_directory_uri().'/includes/js/jquery.masonry.min.js', 'jquery');
		wp_register_script('prettyPhoto', get_template_directory_uri().'/includes/js/prettyPhoto.js', 'jquery');
		wp_register_script('easing', get_template_directory_uri().'/includes/js/jquery.easing.1.3.js', 'jquery');
		wp_register_script('jPlayer', get_template_directory_uri().'/includes/js/jquery.jplayer.min.js', 'jquery');

        wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'masonry' );
		wp_enqueue_script( 'prettyPhoto' );
		wp_enqueue_script( 'jPlayer' );
		wp_enqueue_script( 'easing' );
		
	if(is_page_template('template-portfolio.php'))
		wp_register_script('masonry', get_template_directory_uri().'/includes/js/jquery.masonry.min.js', 'jquery');
		wp_enqueue_script( 'masonry' );
}
add_action('wp_print_scripts', 'tj_non_singular_scripts');


/*-----------------------------------------------------------------------------------*/
/*	Load stylesheets if needed
/*-----------------------------------------------------------------------------------*/

function tj_styles() {
	
	if(!is_singular()){
        wp_register_style( 'prettyPhoto', get_template_directory_uri() . '/includes/css/prettyPhoto.css' );
		wp_enqueue_style( 'prettyPhoto' );
		wp_enqueue_style( 'jPlayer' );
    }
	

		
	if(is_singular() && has_post_format('image') || is_page_template('template-portfolio.php')){
        wp_register_style( 'prettyPhoto', get_template_directory_uri() . '/includes/css/prettyPhoto.css' );
		wp_enqueue_style( 'prettyPhoto' );
    }
}
add_action('init', 'tj_styles');




/*-----------------------------------------------------------------------------------*/
/*	Comment Styling
/*-----------------------------------------------------------------------------------*/

function tj_comment($comment, $args, $depth) {

    $isByAuthor = false;

    if($comment->comment_author_email == get_the_author_meta('email')) {
        $isByAuthor = true;
    }

    $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
     
     <div id="comment-<?php comment_ID(); ?>" class="comment-body clear">
     
      <?php echo get_avatar($comment,$size='35'); ?>
      
      <div class="comment-author vcard">
         <?php printf(__('%s', 'themejunkie'), get_comment_author_link()) ?> 
		 <?php if($isByAuthor) { ?><span class="author-tag"><?php _e('(Author)','themejunkie') ?></span><?php } ?>
      </div>

      <div class="comment-meta commentmetadata">
	  	<?php printf(__('%1$s at %2$s', 'themejunkie'), get_comment_date(),  get_comment_time()) ?>
		<?php edit_comment_link(__('(Edit)', 'themejunkie'),'  ','') ?> &middot; 
		<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </div>
      
      <div class="comment-inner">
      
	  	<?php if ($comment->comment_approved == '0') : ?>
         <em class="moderation"><?php _e('Your comment is awaiting moderation.', 'themejunkie') ?></em>
         <br />
      	<?php endif; ?>
  
   		<?php comment_text() ?>
        
      </div>
      
     </div>

<?php
}


/*-----------------------------------------------------------------------------------*/
/*	Seperated Pings Styling
/*-----------------------------------------------------------------------------------*/

function tj_list_pings($comment, $args, $depth) {
       $GLOBALS['comment'] = $comment; ?>
<li id="comment-<?php comment_ID(); ?>"><?php comment_author_link(); ?>
<?php }


/*-----------------------------------------------------------------------------------*/
/*	Custom Login Logo Support
/*-----------------------------------------------------------------------------------*/

function tj_custom_login_logo() {
    echo '<style type="text/css">
        h1 a { background-image:url('.get_template_directory_uri().'/images/custom-login-logo.png) !important; }
    </style>';
}
function tj_wp_login_url() {
echo home_url();
}
function tj_wp_login_title() {
echo get_option('blogname');
}

add_action('login_head', 'tj_custom_login_logo');
add_filter('login_headerurl', 'tj_wp_login_url');
add_filter('login_headertitle', 'tj_wp_login_title');


/*-----------------------------------------------------------------------------------*/
/*	Helpful function to see if a number is a multiple of another number
/*-----------------------------------------------------------------------------------*/

function is_multiple($number, $multiple)
{
    return ($number % $multiple) == 0;
}

/*-----------------------------------------------------------------------------------*/
/*	Apply JS code for contact page
/*-----------------------------------------------------------------------------------*/

function tj_contact_validate() {
	if (is_page_template('template-contact.php')) { ?>
		<script type="text/javascript">
			jQuery(document).ready(function(){
				jQuery("#contactForm").validate();
			});
		</script>
	<?php }
}
add_action('wp_head', 'tj_contact_validate');

/*-----------------------------------------------------------------------------------*/
/*	Audio JS
/*-----------------------------------------------------------------------------------*/

function tj_audio($postid) {

	$mp3 = get_post_meta($postid, 'tj_audio_mp3', TRUE);
	$ogg = get_post_meta($postid, 'tj_audio_ogg', TRUE);

	if(has_post_format('audio', $postid)) {
	 ?>
		<script type="text/javascript">

			jQuery(document).ready(function(){

				if(jQuery().jPlayer) {
					jQuery("#jquery_jplayer_<?php echo $postid; ?>").jPlayer({
						ready: function () {
							jQuery(this).jPlayer("setMedia", {
								<?php if($mp3 != '') : ?>
								mp3: "<?php echo $mp3; ?>",
								<?php endif; ?>
								<?php if($ogg != '') : ?>
								oga: "<?php echo $ogg; ?>",
								<?php endif; ?>
								end: ""
							});
						},
						swfPath: "<?php echo get_template_directory_uri(); ?>/js",
						cssSelectorAncestor: "#jp_interface_<?php echo $postid; ?>",
						supplied: "<?php if($ogg != '') : ?>oga,<?php endif; ?><?php if($mp3 != '') : ?>mp3, <?php endif; ?> all"
					});

				}
			});
		</script>
	<?php }
}


/*-----------------------------------------------------------------------------------*/
/*	Video JS
/*-----------------------------------------------------------------------------------*/

function tj_video($postid) {

	$m4v = get_post_meta($postid, 'tj_video_m4v', TRUE);
	$ogv = get_post_meta($postid, 'tj_video_ogv', TRUE);
	$poster = get_post_meta($postid, 'tj_video_poster', TRUE);

	if(has_post_format('video', $postid) || get_post_type($postid) == 'portfolio') {
	 ?>
		<script type="text/javascript">
			jQuery(document).ready(function(){

				if(jQuery().jPlayer) {
					jQuery("#jquery_jplayer_<?php echo $postid; ?>").jPlayer({
						ready: function () {
							jQuery(this).jPlayer("setMedia", {
								<?php if($m4v != '') : ?>
								m4v: "<?php echo $m4v; ?>",
								<?php endif; ?>
								<?php if($ogv != '') : ?>
								ogv: "<?php echo $ogv; ?>",
								<?php endif; ?>
								<?php if ($poster != '') : ?>
								poster: "<?php echo $poster; ?>"
								<?php endif; ?>
							});
						},
						swfPath: "<?php echo get_template_directory_uri(); ?>/js",
						cssSelectorAncestor: "#jp_interface_<?php echo $postid; ?>",
						supplied: "<?php if($m4v != '') : ?>m4v, <?php endif; ?><?php if($ogv != '') : ?>ogv, <?php endif; ?> all"
					});

				}
			});
		</script>
	<?php }
}


/* Twitter Widget */
if ( !function_exists( 'tj_twitter_script') ) {
	function tj_twitter_script($unique_id,$username,$limit) {
	?>
	<script type="text/javascript">
	<!--//--><![CDATA[//><!--
	
	    function twitterCallback2(twitters) {
	    
	      var statusHTML = [];
	      for (var i=0; i<twitters.length; i++){
	        var username = twitters[i].user.screen_name;
	        var status = twitters[i].text.replace(/((https?|s?ftp|ssh)\:\/\/[^"\s\<\>]*[^.,;'">\:\s\<\>\)\]\!])/g, function(url) {
	          return '<a href="'+url+'">'+url+'</a>';
	        }).replace(/\B@([_a-z0-9]+)/ig, function(reply) {
	          return  reply.charAt(0)+'<a href="http://twitter.com/'+reply.substring(1)+'">'+reply.substring(1)+'</a>';
	        });
	        statusHTML.push( '<li><span class="content">'+status+'</span> <a style="font-size:85%" class="time" href="http://twitter.com/'+username+'/statuses/'+twitters[i].id_str+'">'+relative_time(twitters[i].created_at)+'</a></li>' );
	      }
	      document.getElementById( 'twitter_update_list_<?php echo $unique_id; ?>').innerHTML = statusHTML.join( '' );
	    }
	    
	    function relative_time(time_value) {
	      var values = time_value.split( " " );
	      time_value = values[1] + " " + values[2] + ", " + values[5] + " " + values[3];
	      var parsed_date = Date.parse(time_value);
	      var relative_to = (arguments.length > 1) ? arguments[1] : new Date();
	      var delta = parseInt((relative_to.getTime() - parsed_date) / 1000);
	      delta = delta + (relative_to.getTimezoneOffset() * 60);
	    
	      if (delta < 60) {
	        return 'less than a minute ago';
	      } else if(delta < 120) {
	        return 'about a minute ago';
	      } else if(delta < (60*60)) {
	        return (parseInt(delta / 60)).toString() + ' minutes ago';
	      } else if(delta < (120*60)) {
	        return 'about an hour ago';
	      } else if(delta < (24*60*60)) {
	        return 'about ' + (parseInt(delta / 3600)).toString() + ' hours ago';
	      } else if(delta < (48*60*60)) {
	        return '1 day ago';
	      } else {
	        return (parseInt(delta / 86400)).toString() + ' days ago';
	      }
	    }
	//-->!]]>
	</script>
	<script type="text/javascript" src="http://api.twitter.com/1/statuses/user_timeline/<?php echo $username; ?>.json?callback=twitterCallback2&amp;count=<?php echo $limit; ?>&amp;include_rts=t"></script>
	<?php
	}
}
    function myfeed_request($qv) {
	    if (isset($qv['feed']))
		    $qv['post_type'] = get_post_types();
	    return $qv;
    }
    add_filter('request', 'myfeed_request');

?>